@@ -2,7 +2,7 @@
 ## Stripe API - ~/lib/Net/API/Stripe/Fraud/ValueList.pm
 ## Version v0.100.0
 ## Copyright(c) 2019 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2020/05/15
 ## 
@@ -10,11 +10,16 @@
 package Net::API::Stripe::Fraud::ValueList;
 BEGIN
 {
-	use strict;
-	use parent qw( Net::API::Stripe::Generic );
-	our( $VERSION ) = 'v0.100.0';
+    use strict;
+    use warnings;
+    use parent qw( Net::API::Stripe::Generic );
+    use vars qw( $VERSION );
+    our( $VERSION ) = 'v0.100.0';
 };
 
+use strict;
+use warnings;
+
 sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
 
 sub object { return( shift->_set_get_scalar( 'object', @_ ) ); }
@@ -68,81 +73,73 @@ Value lists allow you to group values together which can then be referenced in r
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item B<new>( %ARG )
+=head2 new( %ARG )
 
 Creates a new L<Net::API::Stripe::Fraud::ValueList> object.
 
-=back
-
 =head1 METHODS
 
-=over 4
-
-=item B<id> string
+=head2 id string
 
 Unique identifier for the object.
 
-=item B<object> string, value is "radar.value_list"
+=head2 object string, value is "radar.value_list"
 
 String representing the object’s type. Objects of the same type share the same value.
 
-=item B<alias> string
+=head2 alias string
 
 The name of the value list for use in rules.
 
-=item B<created> timestamp
+=head2 created timestamp
 
 Time at which the object was created. Measured in seconds since the Unix epoch.
 
-=item B<created_by> string
+=head2 created_by string
 
 The name or email address of the user who created this value list.
 
-=item B<item_type> string
+=head2 item_type string
 
 The type of items in the value list. One of card_fingerprint, card_bin, email, ip_address, country, string, or case_sensitive_string.
 
-=item B<list_items> list
+=head2 list_items list
 
 List of items contained within this value list.
 
 This is a L<Net::API::Stripe::List> object with array of L<Net::API::Stripe::Fraud::List::Item> objects.
 
-=item B<livemode> boolean
+=head2 livemode boolean
 
 Has the value true if the object exists in live mode or the value false if the object exists in test mode.
 
-=item B<metadata> hash
+=head2 metadata hash
 
 Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
 
-=item B<name> string
+=head2 name string
 
 The name of the value list.
 
-=back
-
 =head1 API SAMPLE
 
-	{
-	  "id": "rsl_fake123456789",
-	  "object": "radar.value_list",
-	  "alias": "custom_ip_blocklist",
-	  "created": 1571480456,
-	  "created_by": "jenny@example.com",
-	  "item_type": "ip_address",
-	  "list_items": {
-		"object": "list",
-		"data": [],
-		"has_more": false,
-		"url": "/v1/radar/value_list_items?value_list=rsl_fake123456789"
-	  },
-	  "livemode": false,
-	  "metadata": {},
-	  "name": "Custom IP Blocklist"
-	}
+    {
+      "id": "rsl_fake123456789",
+      "object": "radar.value_list",
+      "alias": "custom_ip_blocklist",
+      "created": 1571480456,
+      "created_by": "jenny@example.com",
+      "item_type": "ip_address",
+      "list_items": {
+        "object": "list",
+        "data": [],
+        "has_more": false,
+        "url": "/v1/radar/value_list_items?value_list=rsl_fake123456789"
+      },
+      "livemode": false,
+      "metadata": {},
+      "name": "Custom IP Blocklist"
+    }
 
 =head1 HISTORY
 
