@@ -2,7 +2,7 @@
 ## Stripe API - ~/lib/Net/API/Stripe/Payment/Card/List.pm
 ## Version v0.100.0
 ## Copyright(c) 2019 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2020/05/15
 ## 
@@ -11,11 +11,16 @@ package Net::API::Stripe::Payment::Card::List;
 BEGIN
 {
     use strict;
+    use warnings;
     use parent qw( Net::API::Stripe::List );
+    use vars qw( $VERSION );
     our( $VERSION ) = 'v0.100.0';
 };
 
-# sub data { shift->_set_get_object_array( 'data', 'Net::API::Stripe::Payment::Card', @_ ); }
+use strict;
+use warnings;
+
+# sub data { return( shift->_set_get_object_array( 'data', 'Net::API::Stripe::Payment::Card', @_ ) ); }
 
 1;
 
